@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2005  Oliver Burn
+// Copyright (C) 2001-2007  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -256,6 +256,7 @@ public class CheckStyleTask extends Task
      */
     public void execute() throws BuildException
     {
+        final long startTime = System.currentTimeMillis();
         final ClassLoader loader = Thread.currentThread()
                 .getContextClassLoader();
         try {
@@ -265,6 +266,9 @@ public class CheckStyleTask extends Task
         }
         finally {
             Thread.currentThread().setContextClassLoader(loader);
+            final long endTime = System.currentTimeMillis();
+            log("Total execution took " + (endTime - startTime) + " ms.",
+                Project.MSG_VERBOSE);
         }
     }
 
@@ -304,25 +308,37 @@ public class CheckStyleTask extends Task
             c.addListener(warningCounter);
 
             // Process the files
+            long startTime = System.currentTimeMillis();
             final File[] files = scanFileSets();
+            long endTime = System.currentTimeMillis();
+            log("To locate the files took " + (endTime - startTime) + " ms.",
+                Project.MSG_VERBOSE);
 
             log("Running Checkstyle " + version + " on " + files.length
                     + " files", Project.MSG_INFO);
             log("Using configuration " + mConfigLocation, Project.MSG_VERBOSE);
 
+            startTime = System.currentTimeMillis();
             final int numErrs = c.process(files);
+            endTime = System.currentTimeMillis();
+            log("To process the files took " + (endTime - startTime) + " ms.",
+                Project.MSG_VERBOSE);
             final int numWarnings = warningCounter.getCount();
-            final boolean ok = numErrs <= mMaxErrors
-                    && numWarnings <= mMaxWarnings;
+            final boolean ok = (numErrs <= mMaxErrors)
+                    && (numWarnings <= mMaxWarnings);
 
             // Handle the return status
-            if (!ok && mFailureProperty != null) {
-                getProject().setProperty(mFailureProperty, "true");
-            }
+            if (!ok) {
+                final String failureMsg =
+                        "Got " + numErrs + " errors and " + numWarnings
+                                + " warnings.";
+                if (mFailureProperty != null) {
+                    getProject().setProperty(mFailureProperty, failureMsg);
+                }
 
-            if (!ok && mFailOnViolation) {
-                throw new BuildException("Got " + numErrs + " errors and "
-                        + numWarnings + " warnings.", getLocation());
+                if (mFailOnViolation) {
+                    throw new BuildException(failureMsg, getLocation());
+                }
             }
         }
         finally {
@@ -366,7 +382,7 @@ public class CheckStyleTask extends Task
                 c.addListener(listeners[i]);
             }
         }
-        catch (Exception e) {
+        catch (final Exception e) {
             throw new BuildException("Unable to create a Checker: "
                     + e.getMessage(), e);
         }
@@ -391,11 +407,11 @@ public class CheckStyleTask extends Task
                 inStream = new FileInputStream(mPropertiesFile);
                 retVal.load(inStream);
             }
-            catch (FileNotFoundException e) {
+            catch (final FileNotFoundException e) {
                 throw new BuildException("Could not find Properties file '"
                         + mPropertiesFile + "'", e, getLocation());
             }
-            catch (IOException e) {
+            catch (final IOException e) {
                 throw new BuildException("Error loading Properties file '"
                         + mPropertiesFile + "'", e, getLocation());
             }
@@ -405,7 +421,7 @@ public class CheckStyleTask extends Task
                         inStream.close();
                     }
                 }
-                catch (IOException e) {
+                catch (final IOException e) {
                     throw new BuildException("Error closing Properties file '"
                             + mPropertiesFile + "'", e, getLocation());
                 }
@@ -414,14 +430,14 @@ public class CheckStyleTask extends Task
 
         // override with Ant properties like ${basedir}
         final Hashtable antProps = this.getProject().getProperties();
-        for (Iterator it = antProps.keySet().iterator(); it.hasNext();) {
+        for (final Iterator it = antProps.keySet().iterator(); it.hasNext();) {
             final String key = (String) it.next();
             final String value = String.valueOf(antProps.get(key));
             retVal.put(key, value);
         }
 
         // override with properties specified in subelements
-        for (Iterator it = mOverrideProps.iterator(); it.hasNext();) {
+        for (final Iterator it = mOverrideProps.iterator(); it.hasNext();) {
             final Property p = (Property) it.next();
             retVal.put(p.getKey(), p.getValue());
         }
@@ -577,7 +593,7 @@ public class CheckStyleTask extends Task
         private AuditListener createDefaultLogger(Task aTask)
             throws IOException
         {
-            if (mToFile == null || !mUseFile) {
+            if ((mToFile == null) || !mUseFile) {
                 return new DefaultLogger(
                     new LogOutputStream(aTask, Project.MSG_DEBUG),
                     true, new LogOutputStream(aTask, Project.MSG_ERR), true);
@@ -592,7 +608,7 @@ public class CheckStyleTask extends Task
          */
         private AuditListener createXMLLogger(Task aTask) throws IOException
         {
-            if (mToFile == null || !mUseFile) {
+            if ((mToFile == null) || !mUseFile) {
                 return new XMLLogger(new LogOutputStream(aTask,
                         Project.MSG_INFO), true);
             }
