@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2005  Oliver Burn
+// Copyright (C) 2001-2007  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -160,7 +160,7 @@ public class Checker extends AutomaticBean
                     + " is not allowed as a child in Checker");
             }
         }
-        catch (Exception ex) {
+        catch (final Exception ex) {
             // TODO i18n
             throw new CheckstyleException(
                     "cannot initialize module "
@@ -297,9 +297,9 @@ public class Checker extends AutomaticBean
 
         if (!onNetWare) {
             if (!aPath.startsWith(File.separator)
-                && !(aPath.length() >= 2
+                && !((aPath.length() >= 2)
                      && Character.isLetter(aPath.charAt(0))
-                     && colon == 1))
+                     && (colon == 1)))
             {
                 final String msg = aPath + " is not an absolute path";
                 throw new IllegalArgumentException(msg);
@@ -318,10 +318,10 @@ public class Checker extends AutomaticBean
         String root = null;
         // Eliminate consecutive slashes after the drive spec
         if ((!onNetWare
-             && aPath.length() >= 2
+             && (aPath.length() >= 2)
              && Character.isLetter(aPath.charAt(0))
-             && aPath.charAt(1) == ':')
-            || (onNetWare && colon > -1))
+             && (aPath.charAt(1) == ':'))
+            || (onNetWare && (colon > -1)))
         {
 
             dosWithDrive = true;
@@ -341,7 +341,7 @@ public class Checker extends AutomaticBean
             final StringBuffer sbPath = new StringBuffer();
             for (int i = colon + 1; i < ca.length; i++) {
                 if ((ca[i] != '\\')
-                    || (ca[i] == '\\' && ca[i - 1] != '\\'))
+                    || ((ca[i] == '\\') && (ca[i - 1] != '\\')))
                 {
                     sbPath.append(ca[i]);
                 }
