@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2005  Oliver Burn
+// Copyright (C) 2001-2007  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -145,7 +145,7 @@ public final class ConfigurationLoader
                     value = replaceProperties(aAtts.getValue(VALUE),
                         mOverridePropsResolver, aAtts.getValue(DEFAULT));
                 }
-                catch (CheckstyleException ex) {
+                catch (final CheckstyleException ex) {
                     throw new SAXException(ex.getMessage());
                 }
 
@@ -164,7 +164,8 @@ public final class ConfigurationLoader
         {
             if (aQName.equals(MODULE)) {
 
-                Configuration recentModule = (Configuration) mConfigStack.pop();
+                final Configuration recentModule =
+                    (Configuration) mConfigStack.pop();
 
                 // remove modules with severity ignore if these modules should
                 // be omitted
@@ -173,7 +174,7 @@ public final class ConfigurationLoader
                     final String severity = recentModule.getAttribute(SEVERITY);
                     level = SeverityLevel.getInstance(severity);
                 }
-                catch (CheckstyleException e) {
+                catch (final CheckstyleException e) {
                     //severity not set -> ignore
                     ;
                 }
@@ -277,50 +278,87 @@ public final class ConfigurationLoader
      * @return the check configurations
      * @throws CheckstyleException if an error occurs
      */
-    public static Configuration loadConfiguration(
-        String aConfig,
-        PropertyResolver aOverridePropsResolver,
-        boolean aOmitIgnoredModules)
+    public static Configuration loadConfiguration(String aConfig,
+        PropertyResolver aOverridePropsResolver, boolean aOmitIgnoredModules)
         throws CheckstyleException
     {
+        InputStream bufferedStream = null;
         try {
-            final ConfigurationLoader loader =
-                new ConfigurationLoader(aOverridePropsResolver,
-                                        aOmitIgnoredModules);
             // figure out if this is a File or a URL
             InputStream configStream;
             try {
                 final URL url = new URL(aConfig);
                 configStream = url.openStream();
             }
-            catch (MalformedURLException ex) {
+            catch (final MalformedURLException ex) {
                 configStream = new FileInputStream(aConfig);
             }
-            final InputStream bufferedStream =
-                new BufferedInputStream(configStream);
-            loader.parseInputStream(bufferedStream);
-            bufferedStream.close();
+            bufferedStream = new BufferedInputStream(configStream);
+
+            return loadConfiguration(bufferedStream, aOverridePropsResolver,
+                    aOmitIgnoredModules);
+        }
+        catch (final FileNotFoundException e) {
+            throw new CheckstyleException("unable to find " + aConfig, e);
+        }
+        catch (final IOException e) {
+            throw new CheckstyleException("unable to read " + aConfig, e);
+        }
+        catch (final CheckstyleException e) {
+                //wrap again to add file name info
+            throw new CheckstyleException("unable to read " + aConfig + " - "
+                    + e.getMessage(), e);
+        }
+        finally {
+            if (bufferedStream != null) {
+                try {
+                    bufferedStream.close();
+                }
+                catch (final IOException e) {
+                    // cannot throw another exception.
+                    ;
+                }
+            }
+        }
+    }
+
+    /**
+     * Returns the module configurations from a specified input stream.
+     * Note that clients are required to close the given stream by themselves
+     *
+     * @param aConfigStream the input stream to the Checkstyle configuration
+     * @param aOverridePropsResolver overriding properties
+     * @param aOmitIgnoredModules <code>true</code> if modules with severity
+     *            'ignore' should be omitted, <code>false</code> otherwise
+     * @return the check configurations
+     * @throws CheckstyleException if an error occurs
+     */
+    public static Configuration loadConfiguration(InputStream aConfigStream,
+        PropertyResolver aOverridePropsResolver, boolean aOmitIgnoredModules)
+        throws CheckstyleException
+    {
+        try {
+            final ConfigurationLoader loader =
+                new ConfigurationLoader(aOverridePropsResolver,
+                                        aOmitIgnoredModules);
+            loader.parseInputStream(aConfigStream);
             return loader.getConfiguration();
         }
-        catch (FileNotFoundException e) {
+        catch (final ParserConfigurationException e) {
             throw new CheckstyleException(
-                "unable to find " + aConfig, e);
+                "unable to parse configuration stream", e);
         }
-        catch (ParserConfigurationException e) {
-            throw new CheckstyleException(
-                "unable to parse " + aConfig, e);
-        }
-        catch (SAXParseException e) {
-            throw new CheckstyleException("unable to parse "
-                    + aConfig + " - " + e.getMessage() + ":" + e.getLineNumber()
+        catch (final SAXParseException e) {
+            throw new CheckstyleException("unable to parse configuration stream"
+                    + " - " + e.getMessage() + ":" + e.getLineNumber()
                     + ":" + e.getColumnNumber(), e);
         }
-        catch (SAXException e) {
-            throw new CheckstyleException("unable to parse "
-                    + aConfig + " - " + e.getMessage(), e);
+        catch (final SAXException e) {
+            throw new CheckstyleException("unable to parse configuration stream"
+                    + " - " + e.getMessage(), e);
         }
-        catch (IOException e) {
-            throw new CheckstyleException("unable to read " + aConfig, e);
+        catch (final IOException e) {
+            throw new CheckstyleException("unable to read from stream", e);
         }
     }
 
