@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2005  Oliver Burn
+// Copyright (C) 2001-2007  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -134,7 +134,7 @@ public final class TreeWalker
     private final boolean mRecursive;
 
     /** logger for debug purpose */
-    private static Log sLog =
+    private static final Log LOG =
         LogFactory.getLog("com.puppycrawl.tools.checkstyle.TreeWalker");
 
     /**
@@ -146,14 +146,14 @@ public final class TreeWalker
         // Tree walker can use two possible algorithms for
         // tree processing (iterative and recursive.
         // Recursive is default for now.
-        String recursive =
-            System.getProperty("checkstyle.use.recursive.algorithm", "true");
+        final String recursive =
+            System.getProperty("checkstyle.use.recursive.algorithm", "false");
         mRecursive = "true".equals(recursive);
         if (mRecursive) {
-            sLog.debug("TreeWalker uses recursive algorithm");
+            LOG.debug("TreeWalker uses recursive algorithm");
         }
         else {
-            sLog.debug("TreeWalker uses iterative algorithm");
+            LOG.debug("TreeWalker uses iterative algorithm");
         }
     }
 
@@ -188,7 +188,7 @@ public final class TreeWalker
     /** @see com.puppycrawl.tools.checkstyle.api.Configurable */
     public void finishLocalSetup()
     {
-        DefaultContext checkContext = new DefaultContext();
+        final DefaultContext checkContext = new DefaultContext();
         checkContext.add("classLoader", mClassLoader);
         checkContext.add("messages", getMessageCollector());
         checkContext.add("severity", getSeverity());
@@ -243,7 +243,7 @@ public final class TreeWalker
             final DetailAST rootAST = TreeWalker.parse(contents);
             walk(rootAST, contents);
         }
-        catch (FileNotFoundException fnfe) {
+        catch (final FileNotFoundException fnfe) {
             Utils.getExceptionLogger()
                 .debug("FileNotFoundException occured.", fnfe);
             getMessageCollector().add(
@@ -252,9 +252,10 @@ public final class TreeWalker
                     Defn.CHECKSTYLE_BUNDLE,
                     "general.fileNotFound",
                     null,
+                    getId(),
                     this.getClass()));
         }
-        catch (IOException ioe) {
+        catch (final IOException ioe) {
             Utils.getExceptionLogger().debug("IOException occured.", ioe);
             getMessageCollector().add(
                 new LocalizedMessage(
@@ -262,9 +263,10 @@ public final class TreeWalker
                     Defn.CHECKSTYLE_BUNDLE,
                     "general.exception",
                     new String[] {ioe.getMessage()},
+                    getId(),
                     this.getClass()));
         }
-        catch (RecognitionException re) {
+        catch (final RecognitionException re) {
             Utils.getExceptionLogger()
                 .debug("RecognitionException occured.", re);
             getMessageCollector().add(
@@ -274,9 +276,10 @@ public final class TreeWalker
                     Defn.CHECKSTYLE_BUNDLE,
                     "general.exception",
                     new String[] {re.getMessage()},
+                    getId(),
                     this.getClass()));
         }
-        catch (TokenStreamRecognitionException tre) {
+        catch (final TokenStreamRecognitionException tre) {
             Utils.getExceptionLogger()
                 .debug("TokenStreamRecognitionException occured.", tre);
             final RecognitionException re = tre.recog;
@@ -288,6 +291,7 @@ public final class TreeWalker
                         Defn.CHECKSTYLE_BUNDLE,
                         "general.exception",
                         new String[] {re.getMessage()},
+                        getId(),
                         this.getClass()));
             }
             else {
@@ -298,10 +302,11 @@ public final class TreeWalker
                         "general.exception",
                         new String[]
                         {"TokenStreamRecognitionException occured."},
+                        getId(),
                         this.getClass()));
             }
         }
-        catch (TokenStreamException te) {
+        catch (final TokenStreamException te) {
             Utils.getExceptionLogger()
                 .debug("TokenStreamException occured.", te);
             getMessageCollector().add(
@@ -310,9 +315,10 @@ public final class TreeWalker
                     Defn.CHECKSTYLE_BUNDLE,
                     "general.exception",
                     new String[] {te.getMessage()},
+                    getId(),
                     this.getClass()));
         }
-        catch (Throwable err) {
+        catch (final Throwable err) {
             Utils.getExceptionLogger().debug("Throwable occured.", err);
             getMessageCollector().add(
                 new LocalizedMessage(
@@ -320,6 +326,7 @@ public final class TreeWalker
                     Defn.CHECKSTYLE_BUNDLE,
                     "general.exception",
                     new String[] {"" + err},
+                    getId(),
                     this.getClass()));
         }
 
@@ -359,7 +366,7 @@ public final class TreeWalker
                     }
                     // TODO: else log warning
                 }
-                catch (IllegalArgumentException ex) {
+                catch (final IllegalArgumentException ex) {
                     throw new CheckstyleException("illegal token \""
                         + token + "\" in check " + aCheck, ex);
                 }
@@ -527,11 +534,11 @@ public final class TreeWalker
         try {
             rootAST = parse(aContents, true, true, true);
         }
-        catch (RecognitionException exception) {
+        catch (final RecognitionException exception) {
             try {
                 rootAST = parse(aContents, true, true, false);
             }
-            catch (RecognitionException exception2) {
+            catch (final RecognitionException exception2) {
                 rootAST = parse(aContents, false, false, false);
             }
         }
@@ -589,7 +596,7 @@ public final class TreeWalker
      */
     public void destroy()
     {
-        for (Iterator it = mAllChecks.iterator(); it.hasNext();) {
+        for (final Iterator it = mAllChecks.iterator(); it.hasNext();) {
             final Check c = (Check) it.next();
             c.destroy();
         }
@@ -617,7 +624,7 @@ public final class TreeWalker
         while (curNode != null) {
             notifyVisit(curNode);
             DetailAST toVisit = (DetailAST) curNode.getFirstChild();
-            while (curNode != null && toVisit == null) {
+            while ((curNode != null) && (toVisit == null)) {
                 notifyLeave(curNode);
                 toVisit = (DetailAST) curNode.getNextSibling();
                 if (toVisit == null) {
