@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2005  Oliver Burn
+// Copyright (C) 2001-2007  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -18,6 +18,11 @@
 ////////////////////////////////////////////////////////////////////////////////
 package com.puppycrawl.tools.checkstyle.api;
 
+import java.beans.PropertyDescriptor;
+import java.lang.reflect.InvocationTargetException;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.StringTokenizer;
 import org.apache.commons.beanutils.BeanUtilsBean;
 import org.apache.commons.beanutils.ConversionException;
 import org.apache.commons.beanutils.ConvertUtilsBean;
@@ -41,12 +46,6 @@ import org.apache.commons.beanutils.converters.LongConverter;
 import org.apache.commons.beanutils.converters.ShortArrayConverter;
 import org.apache.commons.beanutils.converters.ShortConverter;
 
-import java.beans.PropertyDescriptor;
-import java.lang.reflect.InvocationTargetException;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.StringTokenizer;
-
 
 /**
  * A Java Bean that implements the component lifecycle interfaces by
@@ -70,7 +69,7 @@ public class AutomaticBean
      */
     private static BeanUtilsBean createBeanUtilsBean()
     {
-        ConvertUtilsBean cub = new ConvertUtilsBean();
+        final ConvertUtilsBean cub = new ConvertUtilsBean();
 
         // TODO: is there a smarter way to tell beanutils not to use defaults?
 
@@ -147,7 +146,7 @@ public class AutomaticBean
     {
         mConfiguration = aConfiguration;
 
-        BeanUtilsBean beanUtils = createBeanUtilsBean();
+        final BeanUtilsBean beanUtils = createBeanUtilsBean();
 
         // TODO: debug log messages
         final String[] attributes = aConfiguration.getAttributeNames();
@@ -162,7 +161,7 @@ public class AutomaticBean
                 // figure out if the bean property really exists.
                 final PropertyDescriptor pd =
                     PropertyUtils.getPropertyDescriptor(this, key);
-                if (pd == null || pd.getWriteMethod() == null) {
+                if ((pd == null) || (pd.getWriteMethod() == null)) {
                     throw new CheckstyleException(
                         "Property '" + key + "' in module "
                         + aConfiguration.getName()
@@ -172,28 +171,28 @@ public class AutomaticBean
                 // finally we can set the bean property
                 beanUtils.copyProperty(this, key, value);
             }
-            catch (InvocationTargetException e) {
+            catch (final InvocationTargetException e) {
                 throw new CheckstyleException(
                     "Cannot set property '" + key + "' in module "
                     + aConfiguration.getName() + " to '" + value
                     + "': " + e.getTargetException().getMessage(), e);
             }
-            catch (IllegalAccessException e) {
+            catch (final IllegalAccessException e) {
                 throw new CheckstyleException(
                     "cannot access " + key + " in "
                     + this.getClass().getName(), e);
             }
-            catch (NoSuchMethodException e) {
+            catch (final NoSuchMethodException e) {
                 throw new CheckstyleException(
                     "cannot access " + key + " in "
                     + this.getClass().getName(), e);
             }
-            catch (IllegalArgumentException e) {
+            catch (final IllegalArgumentException e) {
                 throw new CheckstyleException(
                     "illegal value '" + value + "' for property '" + key
                     + "' of module " + aConfiguration.getName(), e);
             }
-            catch (ConversionException e) {
+            catch (final ConversionException e) {
                 throw new CheckstyleException(
                     "illegal value '" + value + "' for property '" + key
                     + "' of module " + aConfiguration.getName(), e);
@@ -219,7 +218,7 @@ public class AutomaticBean
     public final void contextualize(Context aContext)
         throws CheckstyleException
     {
-        BeanUtilsBean beanUtils = createBeanUtilsBean();
+        final BeanUtilsBean beanUtils = createBeanUtilsBean();
 
         // TODO: debug log messages
         final String[] attributes = aContext.getAttributeNames();
@@ -231,24 +230,24 @@ public class AutomaticBean
             try {
                 beanUtils.copyProperty(this, key, value);
             }
-            catch (InvocationTargetException e) {
+            catch (final InvocationTargetException e) {
                 // TODO: log.debug("The bean " + this.getClass()
                 // + " is not interested in " + value)
                 throw new CheckstyleException("cannot set property "
                     + key + " to value " + value + " in bean "
                     + this.getClass().getName(), e);
             }
-            catch (IllegalAccessException e) {
+            catch (final IllegalAccessException e) {
                 throw new CheckstyleException(
                     "cannot access " + key + " in "
                     + this.getClass().getName(), e);
             }
-            catch (IllegalArgumentException e) {
+            catch (final IllegalArgumentException e) {
                 throw new CheckstyleException(
                     "illegal value '" + value + "' for property '" + key
                     + "' of bean " + this.getClass().getName(), e);
             }
-            catch (ConversionException e) {
+            catch (final ConversionException e) {
                 throw new CheckstyleException(
                     "illegal value '" + value + "' for property '" + key
                     + "' of bean " + this.getClass().getName(), e);
@@ -312,7 +311,7 @@ final class StrArrayConverter extends AbstractArrayConverter
     /**
      * <p>Model object for type comparisons.</p>
      */
-    private static String[] sModel = new String[0];
+    private static final String[] MODEL = new String[0];
 
     /**
      * Creates a new StrArrayConverter object.
@@ -359,7 +358,7 @@ final class StrArrayConverter extends AbstractArrayConverter
         }
 
         // Deal with the no-conversion-needed case
-        if (sModel.getClass() == aValue.getClass()) {
+        if (MODEL.getClass() == aValue.getClass()) {
             return (aValue);
         }
 
@@ -374,7 +373,7 @@ final class StrArrayConverter extends AbstractArrayConverter
             }
             return (results);
         }
-        catch (Exception e) {
+        catch (final Exception e) {
             if (useDefault) {
                 return (defaultValue);
             }
@@ -402,7 +401,7 @@ final class StrArrayConverter extends AbstractArrayConverter
      * @throws NullPointerException
      *             if <code>svalue</code> is <code>null</code>
      */
-    protected List parseElements(String aValue)
+    protected List parseElements(final String aValue)
         throws NullPointerException
     {
         // Validate the passed argument
@@ -411,13 +410,12 @@ final class StrArrayConverter extends AbstractArrayConverter
         }
 
         // Trim any matching '{' and '}' delimiters
-        aValue = aValue.trim();
-
-        if (aValue.startsWith("{") && aValue.endsWith("}")) {
-            aValue = aValue.substring(1, aValue.length() - 1);
+        String str = aValue.trim();
+        if (str.startsWith("{") && str.endsWith("}")) {
+            str = str.substring(1, str.length() - 1);
         }
 
-        final StringTokenizer st = new StringTokenizer(aValue, ",");
+        final StringTokenizer st = new StringTokenizer(str, ",");
         final List retVal = new ArrayList();
 
         while (st.hasMoreTokens()) {
