@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2005  Oliver Burn
+// Copyright (C) 2001-2007  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -23,7 +23,6 @@ import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.FullIdent;
 import com.puppycrawl.tools.checkstyle.api.LocalizedMessage;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
-import com.puppycrawl.tools.checkstyle.api.Utils;
 import java.util.HashSet;
 import java.util.HashMap;
 import java.util.Map;
@@ -41,7 +40,7 @@ import java.util.Vector;
 public abstract class AbstractTypeAwareCheck extends Check
 {
     /** imports details **/
-    private Set mImports = new HashSet();
+    private final Set mImports = new HashSet();
 
     /** full identifier for package of the method **/
     private FullIdent mPackageFullIdent;
@@ -53,7 +52,48 @@ public abstract class AbstractTypeAwareCheck extends Check
     private ClassResolver mClassResolver;
 
     /** Stack of maps for type params. */
-    private Vector mTypeParams = new Vector();
+    private final Vector mTypeParams = new Vector();
+
+    /**
+     * Whether to log class loading errors to the checkstyle report
+     * instead of throwing a RTE.
+     *
+     * Logging errors will avoid stopping checkstyle completely
+     * because of a typo in javadoc. However, with modern IDEs that
+     * support automated refactoring and generate javadoc this will
+     * occur rarely, so by default we assume a configuration problem
+     * in the checkstyle classpath and throw an execption.
+     *
+     * This configuration option was triggered by bug 1422462.
+     */
+    private boolean mLogLoadErrors;
+
+    /**
+     * Controls whether to log class loading errors to the checkstyle report
+     * instead of throwing a RTE.
+     *
+     * @param aLogLoadErrors true if errors should be logged
+     */
+    public final void setLogLoadErrors(boolean aLogLoadErrors)
+    {
+        mLogLoadErrors = aLogLoadErrors;
+    }
+
+    /**
+     * Whether to show class loading errors in the checkstyle report.
+     * Request ID 1491630
+     */
+    private boolean mSuppressLoadErrors;
+
+    /**
+     * Controls whether to show class loading errors in the checkstyle report.
+     *
+     * @param aSuppressLoadErrors true if errors shouldn't be shown
+     */
+    public final void setSuppressLoadErrors(boolean aSuppressLoadErrors)
+    {
+        mSuppressLoadErrors = aSuppressLoadErrors;
+    }
 
     /**
      * Called to process an AST when visiting it.
@@ -94,8 +134,8 @@ public abstract class AbstractTypeAwareCheck extends Check
         else if (aAST.getType() == TokenTypes.IMPORT) {
             processImport(aAST);
         }
-        else if (aAST.getType() == TokenTypes.CLASS_DEF
-                 || aAST.getType() == TokenTypes.ENUM_DEF)
+        else if ((aAST.getType() == TokenTypes.CLASS_DEF)
+                 || (aAST.getType() == TokenTypes.ENUM_DEF))
         {
             processClass(aAST);
         }
@@ -110,8 +150,8 @@ public abstract class AbstractTypeAwareCheck extends Check
     /** {@inheritDoc} */
     public final void leaveToken(DetailAST aAST)
     {
-        if (aAST.getType() == TokenTypes.CLASS_DEF
-            || aAST.getType() == TokenTypes.ENUM_DEF)
+        if ((aAST.getType() == TokenTypes.CLASS_DEF)
+            || (aAST.getType() == TokenTypes.ENUM_DEF))
         {
             // perhaps it was inner class
             int dotIdx = mCurrentClass.lastIndexOf("$");
@@ -131,8 +171,8 @@ public abstract class AbstractTypeAwareCheck extends Check
         else if (aAST.getType() == TokenTypes.METHOD_DEF) {
             mTypeParams.remove(mTypeParams.size() - 1);
         }
-        else if (aAST.getType() != TokenTypes.PACKAGE_DEF
-                 && aAST.getType() != TokenTypes.IMPORT)
+        else if ((aAST.getType() != TokenTypes.PACKAGE_DEF)
+                 && (aAST.getType() != TokenTypes.IMPORT))
         {
             leaveAST(aAST);
         }
@@ -148,42 +188,6 @@ public abstract class AbstractTypeAwareCheck extends Check
     {
     }
 
-    /**
-     * Calculate if one type name is a shortname for another type name.
-     * @param aShortName a shorthand, such as <code>IOException</code>
-     * @param aFullName a full name, such as <code>java.io.IOException</code>
-     * @return true iff aShortName represents the same type as aFullName
-     */
-    protected boolean isShortName(String aShortName, String aFullName)
-    {
-        if (aShortName.length() >= aFullName.length()) {
-            return false;
-        }
-
-        final String base = Utils.baseClassname(aFullName);
-        if (aShortName.length() >= aFullName.length()
-                || !base.equals(aShortName))
-        {
-            return false;
-        }
-
-        // check fully qualified import
-        if (mImports.contains(aFullName)) {
-            return true;
-        }
-
-        // check .* import
-        final int endIndex = aFullName.length() - base.length() - 1;
-        final String packageName = aFullName.substring(0, endIndex);
-        final String starImport = packageName + ".*";
-        if (mImports.contains(starImport)) {
-            return true;
-        }
-
-        // check fully qualified class from same package
-        return packageName.equals(mPackageFullIdent.getText());
-    }
-
     /**
      * Is exception is unchecked (subclass of <code>RuntimeException</code>
      * or <code>Error</code>
@@ -214,21 +218,6 @@ public abstract class AbstractTypeAwareCheck extends Check
             &&  aParent.isAssignableFrom(aChild);
     }
 
-    /**
-     * Return if two Strings represent the same type, inspecting the
-     * import statements if necessary
-     *
-     * @param aFirst first type declared in throws clause
-     * @param aSecond second type declared in thros tag
-     * @return true iff type names represent the same type
-     */
-    protected boolean isSameType(String aFirst, String aSecond)
-    {
-        return aFirst.equals(aSecond)
-                || isShortName(aFirst, aSecond)
-                || isShortName(aSecond, aFirst);
-    }
-
     /** @return <code>ClassResolver</code> for current tree. */
     private ClassResolver getClassResolver()
     {
@@ -248,13 +237,12 @@ public abstract class AbstractTypeAwareCheck extends Check
      * @return the resolved class or <code>null</code>
      *          if unable to resolve the class.
      */
-    protected final Class resolveClass(String aClassName,
-                                       String aCurrentClass)
+    protected final Class resolveClass(String aClassName, String aCurrentClass)
     {
         try {
             return getClassResolver().resolve(aClassName, aCurrentClass);
         }
-        catch (ClassNotFoundException e) {
+        catch (final ClassNotFoundException e) {
             return null;
         }
     }
@@ -291,14 +279,21 @@ public abstract class AbstractTypeAwareCheck extends Check
     protected final void logLoadErrorImpl(int aLineNo, int aColumnNo,
                                           String aMsgKey, Object[] aValues)
     {
-        LocalizedMessage msg = new LocalizedMessage(aLineNo,
+        if (!mLogLoadErrors) {
+            final LocalizedMessage msg = new LocalizedMessage(aLineNo,
                                                     aColumnNo,
                                                     getMessageBundle(),
                                                     aMsgKey,
                                                     aValues,
                                                     getSeverityLevel(),
+                                                    getId(),
                                                     this.getClass());
-        throw new RuntimeException(msg.getMessage());
+            throw new RuntimeException(msg.getMessage());
+        }
+
+        if (!mSuppressLoadErrors) {
+            log(aLineNo, aColumnNo, aMsgKey, aValues);
+        }
     }
 
     /**
@@ -332,7 +327,7 @@ public abstract class AbstractTypeAwareCheck extends Check
         final DetailAST typeParams =
             aAST.findFirstToken(TokenTypes.TYPE_PARAMETERS);
 
-        Map paramsMap = new HashMap();
+        final Map paramsMap = new HashMap();
         mTypeParams.add(paramsMap);
 
         if (typeParams == null) {
@@ -344,13 +339,15 @@ public abstract class AbstractTypeAwareCheck extends Check
              child = (DetailAST) child.getNextSibling())
         {
             if (child.getType() == TokenTypes.TYPE_PARAMETER) {
-                DetailAST param = child;
-                String alias = param.findFirstToken(TokenTypes.IDENT).getText();
-                DetailAST bounds =
+                final DetailAST param = child;
+                final String alias =
+                    param.findFirstToken(TokenTypes.IDENT).getText();
+                final DetailAST bounds =
                     param.findFirstToken(TokenTypes.TYPE_UPPER_BOUNDS);
                 if (bounds != null) {
-                    FullIdent name = FullIdent.createFullIdentBelow(bounds);
-                    ClassInfo ci =
+                    final FullIdent name =
+                        FullIdent.createFullIdentBelow(bounds);
+                    final ClassInfo ci =
                         createClassInfo(new Token(name), getCurrentClassName());
                     paramsMap.put(alias, ci);
                 }
@@ -389,7 +386,7 @@ public abstract class AbstractTypeAwareCheck extends Check
     protected final ClassInfo createClassInfo(final Token aName,
                                               final String aSurroundingClass)
     {
-        ClassInfo ci = findClassAlias(aName.getText());
+        final ClassInfo ci = findClassAlias(aName.getText());
         if (ci != null) {
             return new ClassAlias(aName, ci);
         }
@@ -405,7 +402,7 @@ public abstract class AbstractTypeAwareCheck extends Check
     {
         ClassInfo ci = null;
         for (int i = mTypeParams.size() - 1; i >= 0; i--) {
-            Map paramMap = (Map) mTypeParams.get(i);
+            final Map paramMap = (Map) mTypeParams.get(i);
             ci = (ClassInfo) paramMap.get(aName);
             if (ci != null) {
                 break;
@@ -480,7 +477,7 @@ public abstract class AbstractTypeAwareCheck extends Check
         /** @return <code>Class</code> associated with an object. */
         public Class getClazz()
         {
-            if (isLoadable() && mClass == null) {
+            if (isLoadable() && (mClass == null)) {
                 setClazz(mCheck.tryLoadClass(getName(), mSurroundingClass));
             }
             return mClass;
@@ -528,6 +525,13 @@ public abstract class AbstractTypeAwareCheck extends Check
         {
             return mClassInfo.getClazz();
         }
+
+        /** {@inheritDoc} */
+        public String toString()
+        {
+            return "ClassAlias[alias " + getName()
+                + " for " + mClassInfo + "]";
+        }
     }
 
     /**
@@ -583,5 +587,12 @@ public abstract class AbstractTypeAwareCheck extends Check
         {
             return mText;
         }
+
+        /** {@inheritDoc} */
+        public String toString()
+        {
+            return "Token[" + getText() + "(" + getLineNo()
+                + "x" + getColumnNo() + ")]";
+        }
     }
 }
