@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2005  Oliver Burn
+// Copyright (C) 2001-2007  Oliver Burn
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -160,7 +160,7 @@ public class Utils
      */
     public static boolean implementsEntityBean(DetailAST aAST)
     {
-        DetailAST definer = getDefiner(aAST);
+        final DetailAST definer = getDefiner(aAST);
         return ((definer != null)
             && Utils.hasImplements(definer, "javax.ejb.EntityBean"));
     }
@@ -174,7 +174,7 @@ public class Utils
      */
     public static boolean implementsSessionBean(DetailAST aAST)
     {
-        DetailAST definer = getDefiner(aAST);
+        final DetailAST definer = getDefiner(aAST);
         return ((definer != null)
             && Utils.hasImplements(definer, "javax.ejb.SessionBean"));
     }
@@ -188,7 +188,7 @@ public class Utils
      */
     public static boolean isInEJB(DetailAST aAST)
     {
-        DetailAST definer = getDefiner(aAST);
+        final DetailAST definer = getDefiner(aAST);
         return (
             (definer != null)
                 && (Utils.hasImplements(definer, "javax.ejb.SessionBean")
